@@ -9,19 +9,20 @@ from typing import Set
 
 sys.path.append(os.path.dirname(os.path.abspath(__file__)))
 
+import go  # NOQA
 import node  # NOQA
 import python  # NOQA
 import util  # NOQA
 
 
-VERSION = (1, 6, 2)
-__version__ = '.'.join(map(str, VERSION))
+VERSION = (2, 0, 2)
+__version__ = ".".join(map(str, VERSION))
 
 
 DESCRIPTION = (
-    'Update python and node dependencies for your project with git '
-    'integration\n\n'
-    'https://github.com/albertyw/req-update'
+    "Update python, go, and node dependencies for your project with git "
+    "integration\n\n"
+    "https://github.com/albertyw/req-update"
 )
 
 
@@ -29,13 +30,14 @@ def main() -> None:
     ReqUpdate().main()
 
 
-class ReqUpdate():
+class ReqUpdate:
     def __init__(self) -> None:
-        self.install = False
         self.updated_files: Set[str] = set([])
         self.util = util.Util()
         self.python = python.Python()
         self.python.util = self.util
+        self.go = go.Go()
+        self.go.util = self.util
         self.node = node.Node()
         self.node.util = self.util
 
@@ -52,14 +54,20 @@ class ReqUpdate():
             if not branch_created:
                 self.util.create_branch()
                 branch_created = True
-            python_updates = self.python.update_install_dependencies()
+            python_updates = self.python.update_dependencies()
             updates_made = updates_made or python_updates
         if self.node.check_applicable():
             if not branch_created:
                 self.util.create_branch()
                 branch_created = True
-            node_updates = self.node.update_install_dependencies()
+            node_updates = self.node.update_dependencies()
             updates_made = updates_made or node_updates
+        if self.go.check_applicable():
+            if not branch_created:
+                self.util.create_branch()
+                branch_created = True
+            go_updates = self.go.update_dependencies()
+            updates_made = updates_made or go_updates
         if branch_created and not updates_made:
             self.util.rollback_branch()
         return updates_made
@@ -70,36 +78,29 @@ class ReqUpdate():
             formatter_class=argparse.RawTextHelpFormatter,
         )
         parser.add_argument(
-            '-p',
-            '--push',
-            action='store_true',
-            help='Push commits individually to remote origin',
+            "-p",
+            "--push",
+            action="store_true",
+            help="Push commits individually to remote origin",
         )
         parser.add_argument(
-            '-i',
-            '--install',
-            action='store_true',
-            help='Install updates',
+            "-d",
+            "--dryrun",
+            action="store_true",
+            help="Dry run",
         )
         parser.add_argument(
-            '-d',
-            '--dryrun',
-            action='store_true',
-            help='Dry run',
+            "-v",
+            "--verbose",
+            action="store_true",
+            help="Verbose output",
         )
         parser.add_argument(
-            '-v',
-            '--verbose',
-            action='store_true',
-            help='Verbose output',
-        )
-        parser.add_argument(
-            '--version',
-            action='version',
+            "--version",
+            action="version",
             version=__version__,
         )
         args = parser.parse_args()
-        self.install = args.install
         self.util.push = args.push
         self.util.verbose = args.verbose
         self.util.dry_run = args.dryrun
